dbapi.py
changeset 2485 ae74b46ea96c
parent 2476 1294a6bdf3bf
child 2496 fbd1fd2ca312
--- a/dbapi.py	Fri Jul 24 14:59:54 2009 +0200
+++ b/dbapi.py	Fri Jul 24 15:00:49 2009 +0200
@@ -60,7 +60,7 @@
             raise ConnectionError('Could not get repository for %s '
                                   '(not registered in Pyro), '
                                   'you may have to restart your server-side '
-                                  'application' % nsid)
+                                  'instance' % nsid)
         return core.getProxyForURI(uri)
 
 def repo_connect(repo, login, password, cnxprops=None):
@@ -422,8 +422,8 @@
             hm, config = self._repo.hm, self._repo.config
             hm.set_schema(hm.schema) # reset structure
             hm.register_system_hooks(config)
-            # application specific hooks
-            if self._repo.config.application_hooks:
+            # instance specific hooks
+            if self._repo.config.instance_hooks:
                 hm.register_hooks(config.load_hooks(self.vreg))
 
     def source_defs(self):